@@ -138,18 +138,19 @@ class AudioField(FileField):
             conv_freq = "-r %s" % str(freq_value) if freq_value > 0 else ''
 
             conv = "sox %s %s %s %s.wav" % (filename, conv_freq, conv_channel, splitted_filename)
-            result = audio_convert_task.delay(conv)  # commands.getoutput(conv)
+            result = audio_convert_task.delay(conv)
             logger.debug("Sox command :> %s" % conv)
 
         #TODO: CONVERT MP3 TO OGG
         # 2) MP3 TO OGG
+        # not working
         if ext == 'mp3' and CONVERT_TYPE_CHK[convert_type] == 'ogg':
             logger.debug('MP3 to OGG')
             conv = "mpg321 %s -w raw && oggenc raw -o %s.ogg" % (filename,
                                                                  splitted_filename)
-            #conv = "sox  %s  %s.ogg" % (filename, filename)
+            #conv = "sox  %s  %s.ogg" % (filename, splitted_filename)
             #conv = "ffmpeg -i %s  %s.ogg" % (filename, splitted_filename)
-            result = audio_convert_task.delay(conv)  # commands.getoutput(conv)
+            result = audio_convert_task.delay(conv)
             logger.debug("command :> %s" % conv)
 
         # 3) WAV TO MP3
@@ -158,7 +159,7 @@ class AudioField(FileField):
             #conv = "lame -V2 %s %s.mp3" % (filename,  filename)
             #conv = "lame -h %s %s.mp3" % (filename,  filename)
             conv = "sox %s %s.mp3" % (filename, splitted_filename)
-            result = audio_convert_task.delay(conv)  # commands.getoutput(conv)
+            result = audio_convert_task.delay(conv)
             logger.debug("Sox command :> %s" % conv)
 
         # 3) WAV TO WAV
@@ -180,26 +181,24 @@ class AudioField(FileField):
             #create a temp copy of the file
             shutil.copy2(filename, filename_temp)
 
-            result = audio_convert_task.delay(conv)  # commands.getoutput(conv)
+            result = audio_convert_task.delay(conv)
             logger.debug("result :> %s" % str(result))
             logger.debug("command :> %s" % conv)
 
         # 4) WAV TO OGG
-        # not working
         if ext == 'wav' and CONVERT_TYPE_CHK[convert_type] == 'ogg':
             logger.debug('WAV to OGG')
-            #conv = "sox %s %s.ogg" % (filename, splitted_filename)
-            conv = "ffmpeg -i %s  -acodec libvorbis %s.ogg" % (filename, splitted_filename)
-            result = audio_convert_task.delay(conv)  # commands.getoutput(conv)
+            conv = "sox %s %s.ogg" % (filename, splitted_filename)
+            #conv = "ffmpeg -i %s  -acodec libvorbis %s.ogg" % (filename, splitted_filename)
+            result = audio_convert_task.delay(conv)
             logger.debug("command :> %s" % conv)
 
         # 5) OGG TO MP3
-        # not working
         if ext == 'ogg' and CONVERT_TYPE_CHK[convert_type] == 'mp3':
             logger.debug('OGG to MP3')
-            #conv = "sox %s %s.mp3" % (filename, splitted_filename)
-            conv = "ffmpeg -i %s -acodec libmp3lame %s.mp3" % (filename, splitted_filename)
-            result = audio_convert_task.delay(conv)  # commands.getoutput(conv)
+            conv = "sox %s %s.mp3" % (filename, splitted_filename)
+            #conv = "ffmpeg -i %s -acodec libmp3lame %s.mp3" % (filename, splitted_filename)
+            result = audio_convert_task.delay(conv)
             logger.debug("command :> %s" % conv)
 
         # 6) OGG TO WAV
@@ -207,7 +206,7 @@ class AudioField(FileField):
             logger.debug('OGG to WAV')
             #conv = "sox %s %s.wav" % (filename, splitted_filename)
             conv = "ffmpeg -i %s %s.wav" % (filename, splitted_filename)
-            result = audio_convert_task.delay(conv)  # commands.getoutput(conv)
+            result = audio_convert_task.delay(conv)
             logger.debug("command :> %s" % conv)
 
     def _rename_audio(self, instance=None, **kwargs):
